/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface NetappAccountConfig extends cdktf.TerraformMetaArguments {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#id NetappAccount#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#location NetappAccount#location}
    */
    readonly location: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#name NetappAccount#name}
    */
    readonly name: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#resource_group_name NetappAccount#resource_group_name}
    */
    readonly resourceGroupName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#tags NetappAccount#tags}
    */
    readonly tags?: {
        [key: string]: string;
    };
    /**
    * active_directory block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#active_directory NetappAccount#active_directory}
    */
    readonly activeDirectory?: NetappAccountActiveDirectory;
    /**
    * identity block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#identity NetappAccount#identity}
    */
    readonly identity?: NetappAccountIdentity;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#timeouts NetappAccount#timeouts}
    */
    readonly timeouts?: NetappAccountTimeouts;
}
export interface NetappAccountActiveDirectory {
    /**
    * If enabled, AES encryption will be enabled for SMB communication.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#aes_encryption_enabled NetappAccount#aes_encryption_enabled}
    */
    readonly aesEncryptionEnabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#dns_servers NetappAccount#dns_servers}
    */
    readonly dnsServers: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#domain NetappAccount#domain}
    */
    readonly domain: string;
    /**
    * Name of the active directory machine. This optional parameter is used only while creating kerberos volume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#kerberos_ad_name NetappAccount#kerberos_ad_name}
    */
    readonly kerberosAdName?: string;
    /**
    * IP address of the KDC server (usually same the DC). This optional parameter is used only while creating kerberos volume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#kerberos_kdc_ip NetappAccount#kerberos_kdc_ip}
    */
    readonly kerberosKdcIp?: string;
    /**
    * Specifies whether or not the LDAP traffic needs to be secured via TLS.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#ldap_over_tls_enabled NetappAccount#ldap_over_tls_enabled}
    */
    readonly ldapOverTlsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Specifies whether or not the LDAP traffic needs to be signed.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#ldap_signing_enabled NetappAccount#ldap_signing_enabled}
    */
    readonly ldapSigningEnabled?: boolean | cdktf.IResolvable;
    /**
    * If enabled, NFS client local users can also (in addition to LDAP users) access the NFS volumes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#local_nfs_users_with_ldap_allowed NetappAccount#local_nfs_users_with_ldap_allowed}
    */
    readonly localNfsUsersWithLdapAllowed?: boolean | cdktf.IResolvable;
    /**
    * The Organizational Unit (OU) within the Windows Active Directory where machines will be created. If blank, defaults to 'CN=Computers'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#organizational_unit NetappAccount#organizational_unit}
    */
    readonly organizationalUnit?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#password NetappAccount#password}
    */
    readonly password: string;
    /**
    * When LDAP over SSL/TLS is enabled, the LDAP client is required to have base64 encoded Active Directory Certificate Service's self-signed root CA certificate, this optional parameter is used only for dual protocol with LDAP user-mapping volumes.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#server_root_ca_certificate NetappAccount#server_root_ca_certificate}
    */
    readonly serverRootCaCertificate?: string;
    /**
    * The Active Directory site the service will limit Domain Controller discovery to. If blank, defaults to 'Default-First-Site-Name'
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#site_name NetappAccount#site_name}
    */
    readonly siteName?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#smb_server_name NetappAccount#smb_server_name}
    */
    readonly smbServerName: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#username NetappAccount#username}
    */
    readonly username: string;
}
export declare function netappAccountActiveDirectoryToTerraform(struct?: NetappAccountActiveDirectoryOutputReference | NetappAccountActiveDirectory): any;
export declare function netappAccountActiveDirectoryToHclTerraform(struct?: NetappAccountActiveDirectoryOutputReference | NetappAccountActiveDirectory): any;
export declare class NetappAccountActiveDirectoryOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetappAccountActiveDirectory | undefined;
    set internalValue(value: NetappAccountActiveDirectory | undefined);
    private _aesEncryptionEnabled?;
    get aesEncryptionEnabled(): boolean | cdktf.IResolvable;
    set aesEncryptionEnabled(value: boolean | cdktf.IResolvable);
    resetAesEncryptionEnabled(): void;
    get aesEncryptionEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _dnsServers?;
    get dnsServers(): string[];
    set dnsServers(value: string[]);
    get dnsServersInput(): string[] | undefined;
    private _domain?;
    get domain(): string;
    set domain(value: string);
    get domainInput(): string | undefined;
    private _kerberosAdName?;
    get kerberosAdName(): string;
    set kerberosAdName(value: string);
    resetKerberosAdName(): void;
    get kerberosAdNameInput(): string | undefined;
    private _kerberosKdcIp?;
    get kerberosKdcIp(): string;
    set kerberosKdcIp(value: string);
    resetKerberosKdcIp(): void;
    get kerberosKdcIpInput(): string | undefined;
    private _ldapOverTlsEnabled?;
    get ldapOverTlsEnabled(): boolean | cdktf.IResolvable;
    set ldapOverTlsEnabled(value: boolean | cdktf.IResolvable);
    resetLdapOverTlsEnabled(): void;
    get ldapOverTlsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _ldapSigningEnabled?;
    get ldapSigningEnabled(): boolean | cdktf.IResolvable;
    set ldapSigningEnabled(value: boolean | cdktf.IResolvable);
    resetLdapSigningEnabled(): void;
    get ldapSigningEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _localNfsUsersWithLdapAllowed?;
    get localNfsUsersWithLdapAllowed(): boolean | cdktf.IResolvable;
    set localNfsUsersWithLdapAllowed(value: boolean | cdktf.IResolvable);
    resetLocalNfsUsersWithLdapAllowed(): void;
    get localNfsUsersWithLdapAllowedInput(): boolean | cdktf.IResolvable | undefined;
    private _organizationalUnit?;
    get organizationalUnit(): string;
    set organizationalUnit(value: string);
    resetOrganizationalUnit(): void;
    get organizationalUnitInput(): string | undefined;
    private _password?;
    get password(): string;
    set password(value: string);
    get passwordInput(): string | undefined;
    private _serverRootCaCertificate?;
    get serverRootCaCertificate(): string;
    set serverRootCaCertificate(value: string);
    resetServerRootCaCertificate(): void;
    get serverRootCaCertificateInput(): string | undefined;
    private _siteName?;
    get siteName(): string;
    set siteName(value: string);
    resetSiteName(): void;
    get siteNameInput(): string | undefined;
    private _smbServerName?;
    get smbServerName(): string;
    set smbServerName(value: string);
    get smbServerNameInput(): string | undefined;
    private _username?;
    get username(): string;
    set username(value: string);
    get usernameInput(): string | undefined;
}
export interface NetappAccountIdentity {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#identity_ids NetappAccount#identity_ids}
    */
    readonly identityIds?: string[];
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#type NetappAccount#type}
    */
    readonly type: string;
}
export declare function netappAccountIdentityToTerraform(struct?: NetappAccountIdentityOutputReference | NetappAccountIdentity): any;
export declare function netappAccountIdentityToHclTerraform(struct?: NetappAccountIdentityOutputReference | NetappAccountIdentity): any;
export declare class NetappAccountIdentityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetappAccountIdentity | undefined;
    set internalValue(value: NetappAccountIdentity | undefined);
    private _identityIds?;
    get identityIds(): string[];
    set identityIds(value: string[]);
    resetIdentityIds(): void;
    get identityIdsInput(): string[] | undefined;
    get principalId(): string;
    get tenantId(): string;
    private _type?;
    get type(): string;
    set type(value: string);
    get typeInput(): string | undefined;
}
export interface NetappAccountTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#create NetappAccount#create}
    */
    readonly create?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#delete NetappAccount#delete}
    */
    readonly delete?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#read NetappAccount#read}
    */
    readonly read?: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#update NetappAccount#update}
    */
    readonly update?: string;
}
export declare function netappAccountTimeoutsToTerraform(struct?: NetappAccountTimeouts | cdktf.IResolvable): any;
export declare function netappAccountTimeoutsToHclTerraform(struct?: NetappAccountTimeouts | cdktf.IResolvable): any;
export declare class NetappAccountTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): NetappAccountTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: NetappAccountTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
    private _delete?;
    get delete(): string;
    set delete(value: string);
    resetDelete(): void;
    get deleteInput(): string | undefined;
    private _read?;
    get read(): string;
    set read(value: string);
    resetRead(): void;
    get readInput(): string | undefined;
    private _update?;
    get update(): string;
    set update(value: string);
    resetUpdate(): void;
    get updateInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account azurerm_netapp_account}
*/
export declare class NetappAccount extends cdktf.TerraformResource {
    static readonly tfResourceType = "azurerm_netapp_account";
    /**
    * Generates CDKTF code for importing a NetappAccount resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the NetappAccount to import
    * @param importFromId The id of the existing NetappAccount that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the NetappAccount to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/azurerm/3.103.0/docs/resources/netapp_account azurerm_netapp_account} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options NetappAccountConfig
    */
    constructor(scope: Construct, id: string, config: NetappAccountConfig);
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _location?;
    get location(): string;
    set location(value: string);
    get locationInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _resourceGroupName?;
    get resourceGroupName(): string;
    set resourceGroupName(value: string);
    get resourceGroupNameInput(): string | undefined;
    private _tags?;
    get tags(): {
        [key: string]: string;
    };
    set tags(value: {
        [key: string]: string;
    });
    resetTags(): void;
    get tagsInput(): {
        [key: string]: string;
    } | undefined;
    private _activeDirectory;
    get activeDirectory(): NetappAccountActiveDirectoryOutputReference;
    putActiveDirectory(value: NetappAccountActiveDirectory): void;
    resetActiveDirectory(): void;
    get activeDirectoryInput(): NetappAccountActiveDirectory | undefined;
    private _identity;
    get identity(): NetappAccountIdentityOutputReference;
    putIdentity(value: NetappAccountIdentity): void;
    resetIdentity(): void;
    get identityInput(): NetappAccountIdentity | undefined;
    private _timeouts;
    get timeouts(): NetappAccountTimeoutsOutputReference;
    putTimeouts(value: NetappAccountTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | NetappAccountTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
